import 'package:flutter/material.dart';

import '../nb_utils.dart';

Future showConfirmDialog<bool>(context, String title, {positiveText = 'Yes', negativeText = 'No', Color buttonColor}) async {
  return showDialog(
    context: context,
    barrierDismissible: false,
    child: AlertDialog(
      title: Text(title),
      actions: <Widget>[
        SimpleDialogOption(
          child: Text(negativeText, style: secondaryTextStyle()),
          onPressed: () {
            Navigator.of(context).pop(false);
          },
        ),
        SimpleDialogOption(
          onPressed: () {
            Navigator.of(context).pop(true);
          },
          child: Text(positiveText, style: primaryTextStyle(color: buttonColor ?? Theme.of(context).primaryColor)),
        ),
      ],
    ),
  );
}

Future<dynamic> showInDialog(BuildContext context,
    {Widget title,
    Widget child,
    ShapeBorder shape,
    TextStyle titleTextStyle,
    EdgeInsetsGeometry contentPadding = const EdgeInsets.fromLTRB(24.0, 20.0, 24.0, 24.0),
    //bool scrollable = false,
    Color backgroundColor,
    double elevation,
    //EdgeInsets insetPadding = const EdgeInsets.symmetric(horizontal: 16.0, vertical: 16.0),
    List<Widget> actions,
    bool barrierDismissible = true}) async {
  return await showDialog(
    context: context,
    barrierDismissible: barrierDismissible,
    child: AlertDialog(
      content: child,
      shape: shape,
      title: title,
      titleTextStyle: titleTextStyle,
      contentPadding: contentPadding,
      //scrollable: scrollable,
      backgroundColor: backgroundColor,
      elevation: elevation,
      //insetPadding: insetPadding,
      actions: actions,
    ),
  );
}

AppBar appBarWidget(String title, {List<Widget> actions, Color color, bool center = false, automaticallyImplyLeading = true, Color textColor = whiteColor, int textSize = 20}) {
  return AppBar(
    centerTitle: center,
    title: title.text(style: boldTextStyle(color: textColor, size: textSize)),
    actions: actions,
    automaticallyImplyLeading: automaticallyImplyLeading,
    backgroundColor: color,
  );
}
